@@ -2,19 +2,20 @@
  *
  * Copyright © 2007-2008  Emmanuel Pacaud
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author:
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
@@ -45,8 +46,10 @@ typedef struct _LsmDomDocumentClass LsmDomDocumentClass;
 struct _LsmDomDocument {
 	LsmDomNode node;
 
-	GHashTable *		ids;
-	GHashTable *		elements;
+	GHashTable *	ids;
+	GHashTable *	elements;
+
+	char *		url;
 
 	/* Not really a document property, but that simplifies things greatly */
 	double resolution_ppi;
@@ -82,6 +85,12 @@ void 		lsm_dom_document_set_viewport_px 	(LsmDomDocument *self, const LsmBox *vi
 LsmBox 		lsm_dom_document_get_viewport 		(LsmDomDocument *self);
 LsmBox 		lsm_dom_document_get_viewport_px 	(LsmDomDocument *self);
 
+const char * 	lsm_dom_document_get_url 		(LsmDomDocument *self);
+void		lsm_dom_document_set_url		(LsmDomDocument *self, const char *url);
+void 		lsm_dom_document_set_path 		(LsmDomDocument *self, const char *path);
+
+void * 		lsm_dom_document_get_href_data 		(LsmDomDocument *self, const char *href, gsize *size);
+
 G_END_DECLS
 
 #endif
