@@ -122,6 +122,9 @@ lsm_mathml_mode_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_MODE_ERROR,
+			  "LSM_MATHML_MODE_ERROR",
+			  "error" },
 			{ LSM_MATHML_MODE_DISPLAY,
 			  "LSM_MATHML_MODE_DISPLAY",
 			  "display" },
@@ -145,6 +148,9 @@ lsm_mathml_display_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_DISPLAY_ERROR,
+			  "LSM_MATHML_DISPLAY_ERROR",
+			  "error" },
 			{ LSM_MATHML_DISPLAY_BLOCK,
 			  "LSM_MATHML_DISPLAY_BLOCK",
 			  "block" },
@@ -212,6 +218,9 @@ lsm_mathml_unit_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_UNIT_ERROR,
+			  "LSM_MATHML_UNIT_ERROR",
+			  "error" },
 			{ LSM_MATHML_UNIT_NONE,
 			  "LSM_MATHML_UNIT_NONE",
 			  "none" },
@@ -259,15 +268,15 @@ lsm_mathml_font_style_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_FONT_STYLE_ERROR,
+			  "LSM_MATHML_FONT_STYLE_ERROR",
+			  "error" },
 			{ LSM_MATHML_FONT_STYLE_NORMAL,
 			  "LSM_MATHML_FONT_STYLE_NORMAL",
 			  "normal" },
 			{ LSM_MATHML_FONT_STYLE_ITALIC,
 			  "LSM_MATHML_FONT_STYLE_ITALIC",
 			  "italic" },
-			{ LSM_MATHML_FONT_STYLE_ERROR,
-			  "LSM_MATHML_FONT_STYLE_ERROR",
-			  "error" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -285,15 +294,15 @@ lsm_mathml_font_weight_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_FONT_WEIGHT_ERROR,
+			  "LSM_MATHML_FONT_WEIGHT_ERROR",
+			  "error" },
 			{ LSM_MATHML_FONT_WEIGHT_NORMAL,
 			  "LSM_MATHML_FONT_WEIGHT_NORMAL",
 			  "normal" },
 			{ LSM_MATHML_FONT_WEIGHT_BOLD,
 			  "LSM_MATHML_FONT_WEIGHT_BOLD",
 			  "bold" },
-			{ LSM_MATHML_FONT_WEIGHT_ERROR,
-			  "LSM_MATHML_FONT_WEIGHT_ERROR",
-			  "error" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -311,6 +320,9 @@ lsm_mathml_variant_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_VARIANT_ERROR,
+			  "LSM_MATHML_VARIANT_ERROR",
+			  "error" },
 			{ LSM_MATHML_VARIANT_NORMAL,
 			  "LSM_MATHML_VARIANT_NORMAL",
 			  "normal" },
@@ -353,9 +365,6 @@ lsm_mathml_variant_get_type (void)
 			{ LSM_MATHML_VARIANT_MONOSPACE,
 			  "LSM_MATHML_VARIANT_MONOSPACE",
 			  "monospace" },
-			{ LSM_MATHML_VARIANT_ERROR,
-			  "LSM_MATHML_VARIANT_ERROR",
-			  "error" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -373,6 +382,9 @@ lsm_mathml_form_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_FORM_ERROR,
+			  "LSM_MATHML_FORM_ERROR",
+			  "error" },
 			{ LSM_MATHML_FORM_PREFIX,
 			  "LSM_MATHML_FORM_PREFIX",
 			  "prefix" },
@@ -382,9 +394,6 @@ lsm_mathml_form_get_type (void)
 			{ LSM_MATHML_FORM_INFIX,
 			  "LSM_MATHML_FORM_INFIX",
 			  "infix" },
-			{ LSM_MATHML_FORM_ERROR,
-			  "LSM_MATHML_FORM_ERROR",
-			  "error" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -402,6 +411,9 @@ lsm_mathml_row_align_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_ROW_ALIGN_ERROR,
+			  "LSM_MATHML_ROW_ALIGN_ERROR",
+			  "error" },
 			{ LSM_MATHML_ROW_ALIGN_BASELINE,
 			  "LSM_MATHML_ROW_ALIGN_BASELINE",
 			  "baseline" },
@@ -417,9 +429,6 @@ lsm_mathml_row_align_get_type (void)
 			{ LSM_MATHML_ROW_ALIGN_AXIS,
 			  "LSM_MATHML_ROW_ALIGN_AXIS",
 			  "axis" },
-			{ LSM_MATHML_ROW_ALIGN_ERROR,
-			  "LSM_MATHML_ROW_ALIGN_ERROR",
-			  "error" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -437,6 +446,9 @@ lsm_mathml_column_align_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_COLUMN_ALIGN_ERROR,
+			  "LSM_MATHML_COLUMN_ALIGN_ERROR",
+			  "error" },
 			{ LSM_MATHML_COLUMN_ALIGN_CENTER,
 			  "LSM_MATHML_COLUMN_ALIGN_CENTER",
 			  "center" },
@@ -463,6 +475,9 @@ lsm_mathml_line_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_LINE_ERROR,
+			  "LSM_MATHML_LINE_ERROR",
+			  "error" },
 			{ LSM_MATHML_LINE_NONE,
 			  "LSM_MATHML_LINE_NONE",
 			  "none" },
@@ -489,6 +504,9 @@ lsm_mathml_script_level_sign_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_MATHML_SCRIPT_LEVEL_SIGN_ERROR,
+			  "LSM_MATHML_SCRIPT_LEVEL_SIGN_ERROR",
+			  "error" },
 			{ LSM_MATHML_SCRIPT_LEVEL_SIGN_NONE,
 			  "LSM_MATHML_SCRIPT_LEVEL_SIGN_NONE",
 			  "none" },
@@ -733,6 +751,9 @@ lsm_svg_angle_type_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_ANGLE_TYPE_ERROR,
+			  "LSM_SVG_ANGLE_TYPE_ERROR",
+			  "error" },
 			{ LSM_SVG_ANGLE_TYPE_AUTO,
 			  "LSM_SVG_ANGLE_TYPE_AUTO",
 			  "auto" },
@@ -756,6 +777,9 @@ lsm_svg_paint_type_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_PAINT_TYPE_ERROR,
+			  "LSM_SVG_PAINT_TYPE_ERROR",
+			  "error" },
 			{ LSM_SVG_PAINT_TYPE_UNKNOWN,
 			  "LSM_SVG_PAINT_TYPE_UNKNOWN",
 			  "unknown" },
@@ -803,6 +827,9 @@ lsm_svg_length_direction_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_LENGTH_DIRECTION_ERROR,
+			  "LSM_SVG_LENGTH_DIRECTION_ERROR",
+			  "error" },
 			{ LSM_SVG_LENGTH_DIRECTION_HORIZONTAL,
 			  "LSM_SVG_LENGTH_DIRECTION_HORIZONTAL",
 			  "horizontal" },
@@ -829,9 +856,9 @@ lsm_svg_length_type_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ LSM_SVG_LENGTH_TYPE_UNKNOWN,
-			  "LSM_SVG_LENGTH_TYPE_UNKNOWN",
-			  "unknown" },
+			{ LSM_SVG_LENGTH_TYPE_ERROR,
+			  "LSM_SVG_LENGTH_TYPE_ERROR",
+			  "error" },
 			{ LSM_SVG_LENGTH_TYPE_NUMBER,
 			  "LSM_SVG_LENGTH_TYPE_NUMBER",
 			  "number" },
@@ -879,6 +906,9 @@ lsm_svg_fill_rule_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_FILL_RULE_ERROR,
+			  "LSM_SVG_FILL_RULE_ERROR",
+			  "error" },
 			{ LSM_SVG_FILL_RULE_NON_ZERO,
 			  "LSM_SVG_FILL_RULE_NON_ZERO",
 			  "non-zero" },
@@ -902,6 +932,9 @@ lsm_svg_line_join_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_LINE_JOIN_ERROR,
+			  "LSM_SVG_LINE_JOIN_ERROR",
+			  "error" },
 			{ LSM_SVG_LINE_JOIN_MITER,
 			  "LSM_SVG_LINE_JOIN_MITER",
 			  "miter" },
@@ -928,6 +961,9 @@ lsm_svg_line_cap_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_LINE_CAP_ERROR,
+			  "LSM_SVG_LINE_CAP_ERROR",
+			  "error" },
 			{ LSM_SVG_LINE_CAP_BUTT,
 			  "LSM_SVG_LINE_CAP_BUTT",
 			  "butt" },
@@ -954,9 +990,9 @@ lsm_svg_transform_type_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ LSM_SVG_TRANSFORM_TYPE_UNKNOWN,
-			  "LSM_SVG_TRANSFORM_TYPE_UNKNOWN",
-			  "unknown" },
+			{ LSM_SVG_TRANSFORM_TYPE_ERROR,
+			  "LSM_SVG_TRANSFORM_TYPE_ERROR",
+			  "error" },
 			{ LSM_SVG_TRANSFORM_TYPE_MATRIX,
 			  "LSM_SVG_TRANSFORM_TYPE_MATRIX",
 			  "matrix" },
@@ -992,6 +1028,9 @@ lsm_svg_pattern_units_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_PATTERN_UNITS_ERROR,
+			  "LSM_SVG_PATTERN_UNITS_ERROR",
+			  "error" },
 			{ LSM_SVG_PATTERN_UNITS_USER_SPACE_ON_USE,
 			  "LSM_SVG_PATTERN_UNITS_USER_SPACE_ON_USE",
 			  "user-space-on-use" },
@@ -1015,6 +1054,9 @@ lsm_svg_marker_units_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_MARKER_UNITS_ERROR,
+			  "LSM_SVG_MARKER_UNITS_ERROR",
+			  "error" },
 			{ LSM_SVG_MARKER_UNITS_USER_SPACE_ON_USE,
 			  "LSM_SVG_MARKER_UNITS_USER_SPACE_ON_USE",
 			  "user-space-on-use" },
@@ -1038,6 +1080,9 @@ lsm_svg_spread_method_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ LSM_SVG_SPREAD_METHOD_ERROR,
+			  "LSM_SVG_SPREAD_METHOD_ERROR",
+			  "error" },
 			{ LSM_SVG_SPREAD_METHOD_PAD,
 			  "LSM_SVG_SPREAD_METHOD_PAD",
 			  "pad" },
@@ -1064,9 +1109,9 @@ lsm_svg_align_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ LSM_SVG_ALIGN_UNKNOWN,
-			  "LSM_SVG_ALIGN_UNKNOWN",
-			  "unknown" },
+			{ LSM_SVG_ALIGN_ERROR,
+			  "LSM_SVG_ALIGN_ERROR",
+			  "error" },
 			{ LSM_SVG_ALIGN_NONE,
 			  "LSM_SVG_ALIGN_NONE",
 			  "none" },
@@ -1114,9 +1159,9 @@ lsm_svg_meet_or_slice_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ LSM_SVG_MEET_OR_SLICE_UNKNOWN,
-			  "LSM_SVG_MEET_OR_SLICE_UNKNOWN",
-			  "unknown" },
+			{ LSM_SVG_MEET_OR_SLICE_ERROR,
+			  "LSM_SVG_MEET_OR_SLICE_ERROR",
+			  "error" },
 			{ LSM_SVG_MEET_OR_SLICE_MEET,
 			  "LSM_SVG_MEET_OR_SLICE_MEET",
 			  "meet" },
@@ -1132,6 +1177,323 @@ lsm_svg_meet_or_slice_get_type (void)
 	return the_type;
 }
 
+GType
+lsm_svg_comp_op_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ LSM_SVG_COMP_OP_ERROR,
+			  "LSM_SVG_COMP_OP_ERROR",
+			  "error" },
+			{ LSM_SVG_COMP_OP_CLEAR,
+			  "LSM_SVG_COMP_OP_CLEAR",
+			  "clear" },
+			{ LSM_SVG_COMP_OP_SRC,
+			  "LSM_SVG_COMP_OP_SRC",
+			  "src" },
+			{ LSM_SVG_COMP_OP_DST,
+			  "LSM_SVG_COMP_OP_DST",
+			  "dst" },
+			{ LSM_SVG_COMP_OP_SRC_OVER,
+			  "LSM_SVG_COMP_OP_SRC_OVER",
+			  "src-over" },
+			{ LSM_SVG_COMP_OP_DST_OVER,
+			  "LSM_SVG_COMP_OP_DST_OVER",
+			  "dst-over" },
+			{ LSM_SVG_COMP_OP_SRC_IN,
+			  "LSM_SVG_COMP_OP_SRC_IN",
+			  "src-in" },
+			{ LSM_SVG_COMP_OP_DST_IN,
+			  "LSM_SVG_COMP_OP_DST_IN",
+			  "dst-in" },
+			{ LSM_SVG_COMP_OP_SRC_OUT,
+			  "LSM_SVG_COMP_OP_SRC_OUT",
+			  "src-out" },
+			{ LSM_SVG_COMP_OP_DST_OUT,
+			  "LSM_SVG_COMP_OP_DST_OUT",
+			  "dst-out" },
+			{ LSM_SVG_COMP_OP_SRC_ATOP,
+			  "LSM_SVG_COMP_OP_SRC_ATOP",
+			  "src-atop" },
+			{ LSM_SVG_COMP_OP_DST_ATOP,
+			  "LSM_SVG_COMP_OP_DST_ATOP",
+			  "dst-atop" },
+			{ LSM_SVG_COMP_OP_XOR,
+			  "LSM_SVG_COMP_OP_XOR",
+			  "xor" },
+			{ LSM_SVG_COMP_OP_PLUS,
+			  "LSM_SVG_COMP_OP_PLUS",
+			  "plus" },
+			{ LSM_SVG_COMP_OP_MULTIPLY,
+			  "LSM_SVG_COMP_OP_MULTIPLY",
+			  "multiply" },
+			{ LSM_SVG_COMP_OP_SCREEN,
+			  "LSM_SVG_COMP_OP_SCREEN",
+			  "screen" },
+			{ LSM_SVG_COMP_OP_OVERLAY,
+			  "LSM_SVG_COMP_OP_OVERLAY",
+			  "overlay" },
+			{ LSM_SVG_COMP_OP_DARKEN,
+			  "LSM_SVG_COMP_OP_DARKEN",
+			  "darken" },
+			{ LSM_SVG_COMP_OP_LIGHTEN,
+			  "LSM_SVG_COMP_OP_LIGHTEN",
+			  "lighten" },
+			{ LSM_SVG_COMP_OP_COLOR_DODGE,
+			  "LSM_SVG_COMP_OP_COLOR_DODGE",
+			  "color-dodge" },
+			{ LSM_SVG_COMP_OP_COLOR_BURN,
+			  "LSM_SVG_COMP_OP_COLOR_BURN",
+			  "color-burn" },
+			{ LSM_SVG_COMP_OP_HARD_LIGHT,
+			  "LSM_SVG_COMP_OP_HARD_LIGHT",
+			  "hard-light" },
+			{ LSM_SVG_COMP_OP_SOFT_LIGHT,
+			  "LSM_SVG_COMP_OP_SOFT_LIGHT",
+			  "soft-light" },
+			{ LSM_SVG_COMP_OP_DIFFERENCE,
+			  "LSM_SVG_COMP_OP_DIFFERENCE",
+			  "difference" },
+			{ LSM_SVG_COMP_OP_EXCLUSION,
+			  "LSM_SVG_COMP_OP_EXCLUSION",
+			  "exclusion" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("LsmSvgCompOp"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+lsm_svg_font_stretch_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ LSM_SVG_FONT_STRETCH_ERROR,
+			  "LSM_SVG_FONT_STRETCH_ERROR",
+			  "error" },
+			{ LSM_SVG_FONT_STRETCH_NORMAL,
+			  "LSM_SVG_FONT_STRETCH_NORMAL",
+			  "normal" },
+			{ LSM_SVG_FONT_STRETCH_ULTRA_CONDENSED,
+			  "LSM_SVG_FONT_STRETCH_ULTRA_CONDENSED",
+			  "ultra-condensed" },
+			{ LSM_SVG_FONT_STRETCH_EXTRA_CONDENSED,
+			  "LSM_SVG_FONT_STRETCH_EXTRA_CONDENSED",
+			  "extra-condensed" },
+			{ LSM_SVG_FONT_STRETCH_CONDENSED,
+			  "LSM_SVG_FONT_STRETCH_CONDENSED",
+			  "condensed" },
+			{ LSM_SVG_FONT_STRETCH_SEMI_CONDENSED,
+			  "LSM_SVG_FONT_STRETCH_SEMI_CONDENSED",
+			  "semi-condensed" },
+			{ LSM_SVG_FONT_STRETCH_SEMI_EXPANDED,
+			  "LSM_SVG_FONT_STRETCH_SEMI_EXPANDED",
+			  "semi-expanded" },
+			{ LSM_SVG_FONT_STRETCH_EXPANDED,
+			  "LSM_SVG_FONT_STRETCH_EXPANDED",
+			  "expanded" },
+			{ LSM_SVG_FONT_STRETCH_EXTRA_EXPANDED,
+			  "LSM_SVG_FONT_STRETCH_EXTRA_EXPANDED",
+			  "extra-expanded" },
+			{ LSM_SVG_FONT_STRETCH_ULTRA_EXPANDED,
+			  "LSM_SVG_FONT_STRETCH_ULTRA_EXPANDED",
+			  "ultra-expanded" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("LsmSvgFontStretch"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+lsm_svg_font_style_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ LSM_SVG_FONT_STYLE_ERROR,
+			  "LSM_SVG_FONT_STYLE_ERROR",
+			  "error" },
+			{ LSM_SVG_FONT_STYLE_NORMAL,
+			  "LSM_SVG_FONT_STYLE_NORMAL",
+			  "normal" },
+			{ LSM_SVG_FONT_STYLE_OBLIQUE,
+			  "LSM_SVG_FONT_STYLE_OBLIQUE",
+			  "oblique" },
+			{ LSM_SVG_FONT_STYLE_ITALIC,
+			  "LSM_SVG_FONT_STYLE_ITALIC",
+			  "italic" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("LsmSvgFontStyle"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+lsm_svg_font_weight_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ LSM_SVG_FONT_WEIGHT_ERROR,
+			  "LSM_SVG_FONT_WEIGHT_ERROR",
+			  "error" },
+			{ LSM_SVG_FONT_WEIGHT_NORMAL,
+			  "LSM_SVG_FONT_WEIGHT_NORMAL",
+			  "normal" },
+			{ LSM_SVG_FONT_WEIGHT_BOLD,
+			  "LSM_SVG_FONT_WEIGHT_BOLD",
+			  "bold" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("LsmSvgFontWeight"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+lsm_svg_text_anchor_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ LSM_SVG_TEXT_ANCHOR_ERROR,
+			  "LSM_SVG_TEXT_ANCHOR_ERROR",
+			  "error" },
+			{ LSM_SVG_TEXT_ANCHOR_START,
+			  "LSM_SVG_TEXT_ANCHOR_START",
+			  "start" },
+			{ LSM_SVG_TEXT_ANCHOR_MIDDLE,
+			  "LSM_SVG_TEXT_ANCHOR_MIDDLE",
+			  "middle" },
+			{ LSM_SVG_TEXT_ANCHOR_END,
+			  "LSM_SVG_TEXT_ANCHOR_END",
+			  "end" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("LsmSvgTextAnchor"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+lsm_svg_filter_input_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ LSM_SVG_FILTER_INPUT_ERROR,
+			  "LSM_SVG_FILTER_INPUT_ERROR",
+			  "error" },
+			{ LSM_SVG_FILTER_INPUT_SOURCE_GRAPHIC,
+			  "LSM_SVG_FILTER_INPUT_SOURCE_GRAPHIC",
+			  "source-graphic" },
+			{ LSM_SVG_FILTER_INPUT_SOURCE_ALPHA,
+			  "LSM_SVG_FILTER_INPUT_SOURCE_ALPHA",
+			  "source-alpha" },
+			{ LSM_SVG_FILTER_INPUT_BACKGROUND_IMAGE,
+			  "LSM_SVG_FILTER_INPUT_BACKGROUND_IMAGE",
+			  "background-image" },
+			{ LSM_SVG_FILTER_INPUT_BACKGROUND_ALPHA,
+			  "LSM_SVG_FILTER_INPUT_BACKGROUND_ALPHA",
+			  "background-alpha" },
+			{ LSM_SVG_FILTER_INPUT_FILL_PAINT,
+			  "LSM_SVG_FILTER_INPUT_FILL_PAINT",
+			  "fill-paint" },
+			{ LSM_SVG_FILTER_INPUT_STROKE_PAINT,
+			  "LSM_SVG_FILTER_INPUT_STROKE_PAINT",
+			  "stroke-paint" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("LsmSvgFilterInput"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+lsm_svg_element_category_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ LSM_SVG_ELEMENT_CATEGORY_NONE,
+			  "LSM_SVG_ELEMENT_CATEGORY_NONE",
+			  "none" },
+			{ LSM_SVG_ELEMENT_CATEGORY_DESCRIPTIVE,
+			  "LSM_SVG_ELEMENT_CATEGORY_DESCRIPTIVE",
+			  "descriptive" },
+			{ LSM_SVG_ELEMENT_CATEGORY_CONTAINER,
+			  "LSM_SVG_ELEMENT_CATEGORY_CONTAINER",
+			  "container" },
+			{ LSM_SVG_ELEMENT_CATEGORY_STRUCTURAL,
+			  "LSM_SVG_ELEMENT_CATEGORY_STRUCTURAL",
+			  "structural" },
+			{ LSM_SVG_ELEMENT_CATEGORY_GRAPHICS_REFERENCING,
+			  "LSM_SVG_ELEMENT_CATEGORY_GRAPHICS_REFERENCING",
+			  "graphics-referencing" },
+			{ LSM_SVG_ELEMENT_CATEGORY_GRAPHICS,
+			  "LSM_SVG_ELEMENT_CATEGORY_GRAPHICS",
+			  "graphics" },
+			{ LSM_SVG_ELEMENT_CATEGORY_SHAPE,
+			  "LSM_SVG_ELEMENT_CATEGORY_SHAPE",
+			  "shape" },
+			{ LSM_SVG_ELEMENT_CATEGORY_BASIC_SHAPE,
+			  "LSM_SVG_ELEMENT_CATEGORY_BASIC_SHAPE",
+			  "basic-shape" },
+			{ LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT,
+			  "LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT",
+			  "text-content" },
+			{ LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT_CHILD,
+			  "LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT_CHILD",
+			  "text-content-child" },
+			{ LSM_SVG_ELEMENT_CATEGORY_GRADIENT,
+			  "LSM_SVG_ELEMENT_CATEGORY_GRADIENT",
+			  "gradient" },
+			{ LSM_SVG_ELEMENT_CATEGORY_FILTER_PRIMITIVE,
+			  "LSM_SVG_ELEMENT_CATEGORY_FILTER_PRIMITIVE",
+			  "filter-primitive" },
+			{ LSM_SVG_ELEMENT_CATEGORY_ANIMATION,
+			  "LSM_SVG_ELEMENT_CATEGORY_ANIMATION",
+			  "animation" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("LsmSvgElementCategory"),
+				values);
+	}
+	return the_type;
+}
+
 /* enumerations from "lsmsvgview.h" */
 #include "lsmsvgview.h"
 
