@@ -2,19 +2,20 @@
  *
  * Copyright © 2007-2008  Emmanuel Pacaud
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author:
  * 	Emmanuel Pacaud <emmanuel@gnome.org>
@@ -185,7 +186,7 @@ lsm_mathml_view_measure_axis_offset (LsmMathmlView *view,
 
 	axis_offset = pango_units_to_double (- 0.5 * ink_rect.height - ink_rect.y + baseline);
 
-	lsm_debug ("[LsmMathmlView::measure_axis_offset] offset = %g (%g %%)",
+	lsm_debug ("measure", "[LsmMathmlView::measure_axis_offset] offset = %g (%g %%)",
 		   axis_offset, axis_offset / math_size);
 
 	return axis_offset;
@@ -250,7 +251,7 @@ lsm_mathml_view_show_text (LsmMathmlView *view,
 	if (text == NULL || strlen (text) < 1)
 		return;
 
-	lsm_debug ("[LsmMathmlView::show_text] '%s' at %g, %g (size = %g) %s",
+	lsm_debug ("render", "[LsmMathmlView::show_text] '%s' at %g, %g (size = %g) %s",
 		   text, x, y, style->math_size,
 		   lsm_mathml_variant_to_string (style->math_variant));
 
@@ -349,7 +350,7 @@ lsm_mathml_view_measure_operator (LsmMathmlView *view,
 	pango_layout = view->dom_view.measure_pango_layout;
 
 	if (is_stretch_bbox_defined)
-		lsm_debug ("[LsmMathmlView::measure_operator] Stretch bbox w = %g, h = %g, d = %g",
+		lsm_debug ("render", "[LsmMathmlView::measure_operator] Stretch bbox w = %g, h = %g, d = %g",
 			   stretch_bbox->width, stretch_bbox->height, stretch_bbox->depth);
 
 	glyph = lsm_mathml_glyph_table_find_operator_glyph (text);
@@ -358,7 +359,7 @@ lsm_mathml_view_measure_operator (LsmMathmlView *view,
 							 pango_layout, &ink_rect, NULL, &baseline);
 		flags = 0;
 
-		lsm_debug ("[LsmMathmlView::measure_operator] operator = %s", text);
+		lsm_debug ("render", "[LsmMathmlView::measure_operator] operator = %s", text);
 
 	} else {
 		PangoLayoutIter *iter;
@@ -389,7 +390,8 @@ lsm_mathml_view_measure_operator (LsmMathmlView *view,
 			height = pango_units_to_double (ink_rect.height);
 			width = pango_units_to_double (ink_rect.width);
 
-			lsm_debug ("[LsmMathmlView::measure_operator] Glyph #%i -> width = %g, height = %g", i,
+			lsm_debug ("render",
+				   "[LsmMathmlView::measure_operator] Glyph #%i -> width = %g, height = %g", i,
 				    width, height);
 
 			if (!is_stretch_bbox_defined) {
@@ -412,7 +414,7 @@ lsm_mathml_view_measure_operator (LsmMathmlView *view,
 		}
 
 		if (found)
-			lsm_debug ("[LsmMathmlView::measure_operator] Found sized glyph #%i", i);
+			lsm_debug ("render", "[LsmMathmlView::measure_operator] Found sized glyph #%i", i);
 
 		iter = pango_layout_get_iter (pango_layout);
 		baseline = pango_layout_iter_get_baseline (iter);
@@ -482,7 +484,7 @@ lsm_mathml_view_show_operator (LsmMathmlView *view,
 	pango_layout = view->dom_view.measure_pango_layout;
 
 	if (stretch_bbox->is_defined)
-		lsm_debug ("[LsmMathmlView::show_operator] Stretch bbox w = %g, h = %g, d = %g",
+		lsm_debug ("render", "[LsmMathmlView::show_operator] Stretch bbox w = %g, h = %g, d = %g",
 			   stretch_bbox->width, stretch_bbox->height, stretch_bbox->depth);
 
 	glyph = lsm_mathml_glyph_table_find_operator_glyph (text);
@@ -513,7 +515,7 @@ lsm_mathml_view_show_operator (LsmMathmlView *view,
 			pango_layout_set_font_description (pango_layout, font_description);
 			pango_layout_get_extents (pango_layout, &ink_rect, NULL);
 
-			lsm_debug ("[LsmMathmlView::show_operator] Glyph #%i -> width = %g, height = %g", i,
+			lsm_debug ("render", "[LsmMathmlView::show_operator] Glyph #%i -> width = %g, height = %g", i,
 				   pango_units_to_double (ink_rect.width),
 				   pango_units_to_double (ink_rect.height));
 
@@ -539,14 +541,14 @@ lsm_mathml_view_show_operator (LsmMathmlView *view,
 		}
 
 		if (found)
-			lsm_debug ("[LsmMathmlView::show_operator] Found sized glyph #%i", i);
+			lsm_debug ("render", "[LsmMathmlView::show_operator] Found sized glyph #%i", i);
 
 		iter = pango_layout_get_iter (pango_layout);
 		baseline = pango_layout_iter_get_baseline (iter);
 		pango_layout_iter_free (iter);
 	}
 
-	lsm_debug ("[LsmMathmlView::show_operator] '%s' at %g, %g (size = %g) %s - %s",
+	lsm_debug ("render", "[LsmMathmlView::show_operator] '%s' at %g, %g (size = %g) %s - %s",
 		    text, x, y, style->math_size,
 		    style->math_family,
 		    lsm_mathml_variant_to_string (style->math_variant));
@@ -988,7 +990,8 @@ lsm_mathml_view_render (LsmDomView *dom_view)
 
 	lsm_mathml_math_element_render (math_element, view);
 
-	lsm_debug ("[LsmMathmlView::render] cairo status = %s", cairo_status_to_string (cairo_status (cairo)));
+	lsm_debug ("render", "[LsmMathmlView::render] cairo status = %s",
+		   cairo_status_to_string (cairo_status (cairo)));
 }
 
 LsmMathmlView *
