@@ -39,6 +39,11 @@ typedef struct {
 	double value;
 } LsmSvgDoubleAttribute;
 
+typedef struct {
+	LsmAttribute base;
+	LsmSvgOneOrTwoDouble value;
+} LsmSvgOneOrTwoDoubleAttribute;
+
 typedef struct {
 	LsmAttribute base;
 	LsmSvgDashArray *value;
