@@ -38,11 +38,14 @@
 #include <lsmsvgpolygonelement.h>
 #include <lsmsvgpathelement.h>
 #include <lsmsvgtextelement.h>
+#include <lsmsvgtspanelement.h>
 #include <lsmsvglineargradientelement.h>
 #include <lsmsvgradialgradientelement.h>
 #include <lsmsvgstopelement.h>
 #include <lsmsvgpatternelement.h>
 #include <lsmsvgmaskelement.h>
+#include <lsmsvgfilterelement.h>
+#include <lsmsvgfiltergaussianblur.h>
 #include <lsmsvgview.h>
 #include <string.h>
 
@@ -104,6 +107,8 @@ lsm_svg_document_create_element (LsmDomDocument *document, const char *tag_name)
 		node = lsm_svg_polygon_element_new ();
 	else if (strcmp (tag_name, "text") == 0)
 		node = lsm_svg_text_element_new ();
+	else if (strcmp (tag_name, "tspan") == 0)
+		node = lsm_svg_tspan_element_new ();
 	else if (strcmp (tag_name, "linearGradient") == 0)
 		node = lsm_svg_linear_gradient_element_new ();
 	else if (strcmp (tag_name, "radialGradient") == 0)
@@ -126,9 +131,13 @@ lsm_svg_document_create_element (LsmDomDocument *document, const char *tag_name)
 		node = lsm_svg_marker_element_new ();
 	else if (strcmp (tag_name, "clipPath") == 0)
 		node = lsm_svg_clip_path_element_new ();
+	else if (strcmp (tag_name, "filter") == 0)
+		node = lsm_svg_filter_element_new ();
+	else if (strcmp (tag_name, "feGaussianBlur") == 0)
+		node = lsm_svg_filter_gaussian_blur_new ();
 
 	if (node != NULL)
-		lsm_debug ("[LsmSvgDocument::create_element] Create a %s element", tag_name);
+		lsm_debug ("dom", "[LsmSvgDocument::create_element] Create a %s element", tag_name);
 
 	return LSM_DOM_ELEMENT (node);
 }
