@@ -26,7 +26,8 @@
 #include <lsmdomdocument.h>
 #include <lsmsvgelement.h>
 #include <lsmsvgpatternelement.h>
-#include <lsmsvggradientelement.h>
+#include <lsmsvgradialgradientelement.h>
+#include <lsmsvglineargradientelement.h>
 #include <lsmsvgclippathelement.h>
 #include <lsmsvgmarkerelement.h>
 #include <lsmsvgmaskelement.h>
@@ -46,6 +47,12 @@ lsm_svg_element_can_append_child (LsmDomNode *self, LsmDomNode *child)
 static gboolean
 lsm_svg_element_child_changed (LsmDomNode *parent, LsmDomNode *child)
 {
+#if 0
+	if (LSM_IS_SVG_ELEMENT (child) &&
+	    lsm_svg_element_get_category (LSM_SVG_ELEMENT (child)) == 0)
+		g_warning ("Category not defined for '%s'", lsm_dom_node_get_node_name (child));
+#endif
+
 	return TRUE;
 }
 
@@ -57,7 +64,7 @@ lsm_svg_element_set_attribute (LsmDomElement *self, const char* name, const char
 	LsmSvgElementClass *s_element_class = LSM_SVG_ELEMENT_GET_CLASS (self);
 	LsmSvgElement *s_element = LSM_SVG_ELEMENT (self);
 
-	lsm_debug ("[LsmSvgElement::set_attribute] node = %s, name = %s, value = %s",
+	lsm_debug ("dom", "[LsmSvgElement::set_attribute] node = %s, name = %s, value = %s",
 		    lsm_dom_node_get_node_name (LSM_DOM_NODE (self)), name, value);
 
 	/* TODO Avoid double hash table lookup */
@@ -65,7 +72,8 @@ lsm_svg_element_set_attribute (LsmDomElement *self, const char* name, const char
 						  self, name, value))
 		lsm_svg_property_bag_set_property (&s_element->property_bag, name, value);
 
-	if (g_strcmp0 (name, "id") == 0) {
+	if (g_strcmp0 (name, "id") == 0 ||
+	    g_strcmp0 (name, "xml:id") == 0) {
 		LsmDomDocument *document;
 
 		document = lsm_dom_node_get_owner_document (LSM_DOM_NODE (self));
@@ -92,12 +100,20 @@ lsm_svg_element_get_attribute (LsmDomElement *self, const char *name)
 
 /* LsmSvgElement implementation */
 
+LsmSvgElementCategory
+lsm_svg_element_get_category (LsmSvgElement *element)
+{
+	LsmSvgElementClass *s_element_class = LSM_SVG_ELEMENT_GET_CLASS (element);
+
+	return s_element_class != NULL ? s_element_class->category : 0;
+}
+
 static void
 _render (LsmSvgElement *element, LsmSvgView *view)
 {
 	LsmDomNode *node;
 
-	lsm_debug ("[LsmSvgElement::_render");
+	lsm_debug ("render", "[LsmSvgElement::_render");
 
 	lsm_svg_view_push_group_opacity (view);
 
@@ -128,7 +144,7 @@ lsm_svg_element_render (LsmSvgElement *element, LsmSvgView *view)
 
 	element_class = LSM_SVG_ELEMENT_GET_CLASS (element);
 	if (element_class->render != NULL) {
-		lsm_debug ("[LsmSvgElement::render] Render %s (%s)",
+		lsm_debug ("render", "[LsmSvgElement::render] Render %s (%s)",
 			    lsm_dom_node_get_node_name (LSM_DOM_NODE (element)),
 			    element->id.value != NULL ? element->id.value : "no id");
 
@@ -161,7 +177,8 @@ void
 lsm_svg_element_force_render (LsmSvgElement *element, LsmSvgView *view)
 {
 	g_return_if_fail (LSM_IS_SVG_PATTERN_ELEMENT (element) ||
-			  LSM_IS_SVG_GRADIENT_ELEMENT (element) ||
+			  LSM_IS_SVG_RADIAL_GRADIENT_ELEMENT (element) ||
+			  LSM_IS_SVG_LINEAR_GRADIENT_ELEMENT (element) ||
 			  LSM_IS_SVG_MASK_ELEMENT (element) ||
 			  LSM_IS_SVG_CLIP_PATH_ELEMENT (element) ||
 			  LSM_IS_SVG_MARKER_ELEMENT (element));
@@ -171,24 +188,28 @@ lsm_svg_element_force_render (LsmSvgElement *element, LsmSvgView *view)
 }
 
 static void
-_get_extents (LsmSvgElement *self, LsmSvgView *view, LsmExtents *extents)
+_get_extents (LsmSvgElement *element, LsmSvgView *view, LsmExtents *extents)
 {
 	LsmDomNode *node;
 	gboolean first_child = TRUE;
 	LsmExtents element_extents = {0.0, 0.0, 0.0, 0.0};
 
-	lsm_debug ("[LsmSvgGraphic::_graphic_get_extents]");
+	lsm_debug ("render", "[LsmSvgElement::_get_extents]");
 
-	for (node = LSM_DOM_NODE (self)->first_child; node != NULL; node = node->next_sibling) {
+	for (node = LSM_DOM_NODE (element)->first_child; node != NULL; node = node->next_sibling) {
 		if (LSM_IS_SVG_ELEMENT (node)) {
 			LsmExtents child_extents;
+			LsmSvgElement *child_element;
 
-			lsm_svg_element_get_extents (LSM_SVG_ELEMENT (node), view, &child_extents);
+			child_element = LSM_SVG_ELEMENT (node);
+
+			lsm_svg_element_get_extents (child_element, view, &child_extents);
+
+			if (!lsm_svg_matrix_is_identity (&child_element->transform.matrix))
+				lsm_svg_matrix_transform_bounding_box (&child_element->transform.matrix,
+								       &extents->x1, &extents->y1,
+								       &extents->x2, &extents->y2);
 
-			if (!lsm_svg_matrix_is_identity (&self->transform.matrix))
-				lsm_svg_matrix_transform_bounding_box (&self->transform.matrix,
-								       &child_extents.x1, &child_extents.y1,
-								       &child_extents.x2, &child_extents.y2);
 			if (first_child) {
 				element_extents = child_extents;
 				first_child = FALSE;
@@ -217,9 +238,14 @@ lsm_svg_element_get_extents (LsmSvgElement *element, LsmSvgView *view, LsmExtent
 	if (element_class->get_extents != NULL) {
 		element_class->get_extents (element, view, extents);
 
-		lsm_debug ("LsmSvgElement::get_extents] Exents for '%s' = %g,%g %g,%g",
-			   lsm_dom_node_get_node_name (LSM_DOM_NODE (element)),
-			   extents->x1, extents->y1, extents->x2, extents->y2);
+		if (element->id.value != NULL)
+			lsm_debug ("measure", "LsmSvgElement::get_extents] Extents for '%s' = %g,%g %g,%g",
+				   element->id.value,
+				   extents->x1, extents->y1, extents->x2, extents->y2);
+		else
+			lsm_debug ("measure", "LsmSvgElement::get_extents] Extents for <%s> = %g,%g %g,%g",
+				   lsm_dom_node_get_node_name (LSM_DOM_NODE (element)),
+				   extents->x1, extents->y1, extents->x2, extents->y2);
 	} else {
 		extents->x1 = 0.0;
 		extents->y1 = 0.0;
@@ -256,6 +282,11 @@ static const LsmAttributeInfos lsm_svg_attribute_infos[] = {
 		.trait_class = &lsm_null_trait_class,
 		.attribute_offset = offsetof (LsmSvgElement, id)
 	},
+	{
+		.name = "xml:id",
+		.trait_class = &lsm_null_trait_class,
+		.attribute_offset = offsetof (LsmSvgElement, id)
+	},
 	{
 		.name = "class",
 		.trait_class = &lsm_null_trait_class,
@@ -286,6 +317,8 @@ lsm_svg_element_class_init (LsmSvgElementClass *s_element_class)
 	d_element_class->get_attribute = lsm_svg_element_get_attribute;
 	d_element_class->set_attribute = lsm_svg_element_set_attribute;
 
+	s_element_class->category = 0;
+
 	s_element_class->render = _render;
 	s_element_class->get_extents = _get_extents;
 	s_element_class->attribute_manager = lsm_attribute_manager_new (G_N_ELEMENTS (lsm_svg_attribute_infos),
