@@ -21,6 +21,7 @@
  */
 
 #include <lsmsvgtextelement.h>
+#include <lsmsvgtspanelement.h>
 #include <lsmsvgview.h>
 #include <lsmdomtext.h>
 
@@ -37,7 +38,7 @@ lsm_svg_text_element_get_node_name (LsmDomNode *node)
 static gboolean
 lsm_svg_text_element_can_append_child (LsmDomNode *self, LsmDomNode *child)
 {
-	return (LSM_IS_DOM_TEXT (child));
+	return (LSM_IS_SVG_TSPAN_ELEMENT (child) || LSM_IS_DOM_TEXT (child));
 }
 
 /* LsmSvgElement implementation */
@@ -68,6 +69,10 @@ lsm_svg_text_element_render (LsmSvgElement *self, LsmSvgView *view)
 	lsm_svg_view_show_text (view, g_strstrip (string->str), x, y);
 
 	g_string_free (string, TRUE);
+
+	for (iter = LSM_DOM_NODE (self)->first_child; iter != NULL; iter = iter->next_sibling)
+		if (LSM_IS_SVG_ELEMENT (iter))
+		    lsm_svg_element_render (LSM_SVG_ELEMENT (iter), view);
 }
 
 /* LsmSvgTextElement implementation */
@@ -124,6 +129,10 @@ lsm_svg_text_element_class_init (LsmSvgTextElementClass *s_text_class)
 	d_node_class->get_node_name = lsm_svg_text_element_get_node_name;
 	d_node_class->can_append_child = lsm_svg_text_element_can_append_child;
 
+	s_element_class->category =
+		LSM_SVG_ELEMENT_CATEGORY_GRAPHICS |
+		LSM_SVG_ELEMENT_CATEGORY_TEXT_CONTENT;
+
 	s_element_class->render = lsm_svg_text_element_render;
 	s_element_class->attribute_manager = lsm_attribute_manager_duplicate (s_element_class->attribute_manager);
 
