@@ -25,18 +25,21 @@
 #include <lsmsvgcolors.h>
 #include <math.h>
 #include <string.h>
+#include <stdlib.h>
 
 const LsmSvgColor lsm_svg_color_null = {0.0, 0.0, 0.0};
 const LsmSvgDashArray lsm_svg_dash_array_null = {0, NULL};
 
-static void
+static gboolean
 lsm_svg_length_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgLength *svg_length = (LsmSvgLength *) abstract_trait;
 	char *length_type_str;
 
-	svg_length->value_unit = g_strtod (string, &length_type_str);
+	svg_length->value_unit = g_ascii_strtod (string, &length_type_str);
 	svg_length->type = lsm_svg_length_type_from_string (length_type_str);
+
+	return length_type_str != string && svg_length->type >= 0;
 }
 
 static char *
@@ -119,7 +122,7 @@ _init_matrix (LsmSvgMatrix *matrix, LsmSvgTransformType transform, unsigned int
 	lsm_svg_matrix_init_identity (matrix);
 }
 
-static void
+static gboolean
 lsm_svg_matrix_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgMatrix *matrix = (LsmSvgMatrix *) abstract_trait;
@@ -151,7 +154,7 @@ lsm_svg_matrix_trait_from_string (LsmTrait *abstract_trait, char *string)
 			transform = LSM_SVG_TRANSFORM_TYPE_SKEW_Y;
 			string += 5;
 		} else
-			break;
+			return FALSE;
 
 		lsm_str_skip_spaces (&string);
 
@@ -179,9 +182,13 @@ lsm_svg_matrix_trait_from_string (LsmTrait *abstract_trait, char *string)
 				_init_matrix (&new_matrix, transform, n_values, values);
 
 				lsm_svg_matrix_multiply (matrix, &new_matrix, matrix);
-			}
-		}
+			} else
+				return FALSE;
+		} else
+			return FALSE;
 	}
+
+	return TRUE;
 }
 
 static char *
@@ -258,6 +265,8 @@ _parse_color (char *string,
 
 		string += 4; /* strlen ("rgb(") */
 
+		lsm_str_skip_spaces (&string);
+
 		for (i = 0; i < 3; i++) {
 			if (!lsm_str_parse_double (&string, &value))
 				break;
@@ -294,7 +303,7 @@ _parse_color (char *string,
 	return string;
 }
 
-static void
+static gboolean
 lsm_svg_paint_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgPaint *paint = (LsmSvgPaint *) abstract_trait;
@@ -342,6 +351,10 @@ lsm_svg_paint_trait_from_string (LsmTrait *abstract_trait, char *string)
 		}
 
 	paint->type = paint_type;
+
+	/* TODO better syntax error check */
+
+	return TRUE;
 }
 
 char *
@@ -368,12 +381,14 @@ const LsmTraitClass lsm_svg_paint_trait_class = {
 	.to_string = lsm_svg_paint_trait_to_string
 };
 
-static void
+static gboolean
 lsm_svg_fill_rule_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgFillRule *trait = (LsmSvgFillRule *) abstract_trait;
 
 	*trait = lsm_svg_fill_rule_from_string (string);
+
+	return *trait >= 0;
 }
 
 char *
@@ -390,12 +405,95 @@ const LsmTraitClass lsm_svg_fill_rule_trait_class = {
 	.to_string = lsm_svg_fill_rule_trait_to_string
 };
 
-static void
+static gboolean
+lsm_svg_font_style_trait_from_string (LsmTrait *abstract_trait, char *string)
+{
+	LsmSvgFontStyle *trait = (LsmSvgFontStyle *) abstract_trait;
+
+	*trait = lsm_svg_font_style_from_string (string);
+
+	return *trait >= 0;
+}
+
+char *
+lsm_svg_font_style_trait_to_string (LsmTrait *abstract_trait)
+{
+	LsmSvgFontStyle *trait = (LsmSvgFontStyle *) abstract_trait;
+
+	return g_strdup (lsm_svg_font_style_to_string (*trait));
+}
+
+const LsmTraitClass lsm_svg_font_style_trait_class = {
+	.size = sizeof (LsmSvgFontStyle),
+	.from_string = lsm_svg_font_style_trait_from_string,
+	.to_string = lsm_svg_font_style_trait_to_string
+};
+
+static gboolean
+lsm_svg_font_stretch_trait_from_string (LsmTrait *abstract_trait, char *string)
+{
+	LsmSvgFontStretch *trait = (LsmSvgFontStretch *) abstract_trait;
+
+	*trait = lsm_svg_font_stretch_from_string (string);
+
+	return *trait >= 0;
+}
+
+char *
+lsm_svg_font_stretch_trait_to_string (LsmTrait *abstract_trait)
+{
+	LsmSvgFontStretch *trait = (LsmSvgFontStretch *) abstract_trait;
+
+	return g_strdup (lsm_svg_font_stretch_to_string (*trait));
+}
+
+const LsmTraitClass lsm_svg_font_stretch_trait_class = {
+	.size = sizeof (LsmSvgFontStretch),
+	.from_string = lsm_svg_font_stretch_trait_from_string,
+	.to_string = lsm_svg_font_stretch_trait_to_string
+};
+
+static gboolean
+lsm_svg_font_weight_trait_from_string (LsmTrait *abstract_trait, char *string)
+{
+	LsmSvgFontWeight *trait = (LsmSvgFontWeight *) abstract_trait;
+
+	*trait = lsm_svg_font_weight_from_string (string);
+
+	if (*trait < 0)
+		*trait = strtol (string, NULL, 10);
+
+	return *trait >= 100 && *trait <= 1000;
+}
+
+char *
+lsm_svg_font_weight_trait_to_string (LsmTrait *abstract_trait)
+{
+	LsmSvgFontWeight *trait = (LsmSvgFontWeight *) abstract_trait;
+	const char *string;
+
+	string = lsm_svg_font_weight_to_string (*trait);
+
+	if (string != NULL)
+		return g_strdup (string);
+
+	return g_strdup_printf ("%d", *trait);
+}
+
+const LsmTraitClass lsm_svg_font_weight_trait_class = {
+	.size = sizeof (LsmSvgFontWeight),
+	.from_string = lsm_svg_font_weight_trait_from_string,
+	.to_string = lsm_svg_font_weight_trait_to_string
+};
+
+static gboolean
 lsm_svg_line_join_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgLineJoin *trait = (LsmSvgLineJoin *) abstract_trait;
 
 	*trait = lsm_svg_line_join_from_string (string);
+
+	return *trait >= 0;
 }
 
 char *
@@ -412,12 +510,14 @@ const LsmTraitClass lsm_svg_line_join_trait_class = {
 	.to_string = lsm_svg_line_join_trait_to_string
 };
 
-static void
+static gboolean
 lsm_svg_line_cap_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgLineCap *trait = (LsmSvgLineCap *) abstract_trait;
 
 	*trait = lsm_svg_line_cap_from_string (string);
+
+	return *trait >= 0;
 }
 
 static char *
@@ -474,11 +574,14 @@ lsm_svg_dash_array_duplicate (const LsmSvgDashArray *origin)
 	return duplicate;
 }
 
-static void
+static gboolean
 lsm_svg_dash_array_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgDashArray *dash_array = (LsmSvgDashArray *) abstract_trait;
 	unsigned int n_dashes = 1;
+	double value;
+	double sum = 0.0;
+	gboolean is_error = FALSE;
 
 	g_free (dash_array->dashes);
 	dash_array->n_dashes = 0;
@@ -511,12 +614,29 @@ lsm_svg_dash_array_trait_from_string (LsmTrait *abstract_trait, char *string)
 						iter ++;
 				} else {
 					dash_array->dashes[i].value_unit = 0.0;
-					dash_array->dashes[i].value_unit = LSM_SVG_LENGTH_TYPE_NUMBER;
+					dash_array->dashes[i].type = LSM_SVG_LENGTH_TYPE_NUMBER;
 				}
 				lsm_str_skip_comma_and_spaces (&iter);
+
+				value = dash_array->dashes[i].value_unit;
+				if (value < 0.0) {
+					is_error = TRUE;
+					break;
+				}
+				sum += value;
 			}
 		}
 	}
+
+	if (is_error || sum <= 0.0) {
+		g_free (dash_array->dashes);
+		dash_array->n_dashes = 0;
+		dash_array->dashes = NULL;
+
+		return !is_error;
+	}
+
+	return TRUE;
 }
 
 static char *
@@ -542,13 +662,17 @@ const LsmTraitClass lsm_svg_dash_array_trait_class = {
 	.finalize = lsm_svg_dash_array_trait_finalize
 };
 
-static void
+static gboolean
 lsm_svg_color_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgColor *color = (LsmSvgColor *) abstract_trait;
 	LsmSvgPaintType paint_type;
 
 	_parse_color (string, color, &paint_type);
+
+	/* TODO Better error check */
+
+	return TRUE;
 }
 
 static char *
@@ -571,12 +695,14 @@ const LsmTraitClass lsm_svg_color_trait_class = {
 	.to_string = lsm_svg_color_trait_to_string
 };
 
-static void
+static gboolean
 lsm_svg_marker_units_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgMarkerUnits *trait = (LsmSvgMarkerUnits *) abstract_trait;
 
 	*trait = lsm_svg_marker_units_from_string (string);
+
+	return *trait >= 0;
 }
 
 char *
@@ -593,12 +719,14 @@ const LsmTraitClass lsm_svg_marker_units_trait_class = {
 	.to_string = lsm_svg_marker_units_trait_to_string
 };
 
-static void
+static gboolean
 lsm_svg_pattern_units_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgPatternUnits *trait = (LsmSvgPatternUnits *) abstract_trait;
 
 	*trait = lsm_svg_pattern_units_from_string (string);
+
+	return *trait >= 0;
 }
 
 char *
@@ -615,7 +743,7 @@ const LsmTraitClass lsm_svg_pattern_units_trait_class = {
 	.to_string = lsm_svg_pattern_units_trait_to_string
 };
 
-static void
+static gboolean
 lsm_svg_preserve_aspect_ratio_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgPreserveAspectRatio *trait = (LsmSvgPreserveAspectRatio *) abstract_trait;
@@ -641,6 +769,10 @@ lsm_svg_preserve_aspect_ratio_trait_from_string (LsmTrait *abstract_trait, char
 	} else trait->align = LSM_SVG_ALIGN_X_MID_Y_MID;
 
 	g_strfreev (tokens);
+
+	/* TODO Better error check */
+
+	return TRUE;
 }
 
 char *
@@ -659,12 +791,14 @@ const LsmTraitClass lsm_svg_preserve_aspect_ratio_trait_class = {
 	.to_string = lsm_svg_preserve_aspect_ratio_trait_to_string
 };
 
-static void
+static gboolean
 lsm_svg_spread_method_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgSpreadMethod *trait = (LsmSvgSpreadMethod *) abstract_trait;
 
 	*trait = lsm_svg_spread_method_from_string (string);
+
+	return *trait >= 0;
 }
 
 static char *
@@ -681,18 +815,23 @@ const LsmTraitClass lsm_svg_spread_method_trait_class = {
 	.to_string = lsm_svg_spread_method_trait_to_string
 };
 
-static void
+static gboolean
 lsm_svg_angle_trait_from_string (LsmTrait *abstract_trait, char *string)
 {
 	LsmSvgAngle *trait = (LsmSvgAngle *) abstract_trait;
+	char *end_ptr;
 
 	if (g_strcmp0 (string, "auto") == 0) {
 		trait->type = LSM_SVG_ANGLE_TYPE_AUTO;
 		trait->angle = 0.0;
-	} else {
-		trait->type = LSM_SVG_ANGLE_TYPE_FIXED;
-		trait->angle = g_strtod (string, NULL);
+
+		return TRUE;
 	}
+
+	trait->type = LSM_SVG_ANGLE_TYPE_FIXED;
+	trait->angle = g_ascii_strtod (string, &end_ptr);
+
+	return end_ptr != string;
 }
 
 static char *
@@ -711,3 +850,69 @@ const LsmTraitClass lsm_svg_angle_trait_class = {
 	.from_string = lsm_svg_angle_trait_from_string,
 	.to_string = lsm_svg_angle_trait_to_string
 };
+
+static gboolean
+lsm_svg_text_anchor_trait_from_string (LsmTrait *abstract_trait, char *string)
+{
+	LsmSvgTextAnchor *trait = (LsmSvgTextAnchor *) abstract_trait;
+
+	*trait = lsm_svg_text_anchor_from_string (string);
+
+	return *trait >= 0;
+}
+
+char *
+lsm_svg_text_anchor_trait_to_string (LsmTrait *abstract_trait)
+{
+	LsmSvgTextAnchor *trait = (LsmSvgTextAnchor *) abstract_trait;
+
+	return g_strdup (lsm_svg_text_anchor_to_string (*trait));
+}
+
+const LsmTraitClass lsm_svg_text_anchor_trait_class = {
+	.size = sizeof (LsmSvgTextAnchor),
+	.from_string = lsm_svg_text_anchor_trait_from_string,
+	.to_string = lsm_svg_text_anchor_trait_to_string
+};
+
+static gboolean
+lsm_svg_one_or_two_double_trait_from_string (LsmTrait *abstract_trait, char *string)
+{
+	LsmSvgOneOrTwoDouble *trait = (LsmSvgOneOrTwoDouble *) abstract_trait;
+	char *end_ptr;
+
+	trait->a = g_ascii_strtod (string, &end_ptr);
+	if (end_ptr == string) {
+		trait->b = 0.0;
+		return FALSE;
+	}
+
+	lsm_str_skip_spaces (&string);
+
+	if (string[0] == '\0') {
+		trait->b = trait->a;
+		return TRUE;
+	}
+
+	trait->b = g_ascii_strtod (string, &end_ptr);
+
+	return end_ptr != string;
+}
+
+static char *
+lsm_svg_one_or_two_double_trait_to_string (LsmTrait *abstract_trait)
+{
+	LsmSvgOneOrTwoDouble *trait = (LsmSvgOneOrTwoDouble *) abstract_trait;
+
+	if (trait->a == trait->b)
+		return g_strdup_printf ("%g", trait->a);
+
+	return g_strdup_printf ("%g %g", trait->a, trait->b);
+}
+
+const LsmTraitClass lsm_svg_one_or_two_double_trait_class = {
+	.size = sizeof (double),
+	.from_string = lsm_svg_one_or_two_double_trait_from_string,
+	.to_string = lsm_svg_one_or_two_double_trait_to_string
+};
+
