@@ -29,6 +29,11 @@
 
 G_BEGIN_DECLS
 
+typedef struct {
+	LsmSvgAngleType type;
+	double angle;
+} LsmSvgAngle;
+
 typedef struct {
 	double red;
 	double green;
@@ -62,23 +67,28 @@ typedef struct {
 } LsmSvgPreserveAspectRatio;
 
 typedef struct {
-	LsmSvgAngleType type;
-	double angle;
-} LsmSvgAngle;
+	double a;
+	double b;
+} LsmSvgOneOrTwoDouble;
 
-extern const LsmTraitClass lsm_svg_length_trait_class;
-extern const LsmTraitClass lsm_svg_matrix_trait_class;
-extern const LsmTraitClass lsm_svg_paint_trait_class;
+extern const LsmTraitClass lsm_svg_angle_trait_class;
+extern const LsmTraitClass lsm_svg_color_trait_class;
+extern const LsmTraitClass lsm_svg_dash_array_trait_class;
 extern const LsmTraitClass lsm_svg_fill_rule_trait_class;
+extern const LsmTraitClass lsm_svg_font_stretch_trait_class;
+extern const LsmTraitClass lsm_svg_font_style_trait_class;
+extern const LsmTraitClass lsm_svg_font_weight_trait_class;
+extern const LsmTraitClass lsm_svg_length_trait_class;
 extern const LsmTraitClass lsm_svg_line_join_trait_class;
 extern const LsmTraitClass lsm_svg_line_cap_trait_class;
-extern const LsmTraitClass lsm_svg_dash_array_trait_class;
-extern const LsmTraitClass lsm_svg_color_trait_class;
-extern const LsmTraitClass lsm_svg_pattern_units_trait_class;
 extern const LsmTraitClass lsm_svg_marker_units_trait_class;
+extern const LsmTraitClass lsm_svg_matrix_trait_class;
+extern const LsmTraitClass lsm_svg_one_or_two_double_trait_class;
+extern const LsmTraitClass lsm_svg_paint_trait_class;
+extern const LsmTraitClass lsm_svg_pattern_units_trait_class;
 extern const LsmTraitClass lsm_svg_preserve_aspect_ratio_trait_class;
 extern const LsmTraitClass lsm_svg_spread_method_trait_class;
-extern const LsmTraitClass lsm_svg_angle_trait_class;
+extern const LsmTraitClass lsm_svg_text_anchor_trait_class;
 
 G_END_DECLS
 
